"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Copyright (c) 2018, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
const vscode_1 = require("vscode");
const path = require("path");
const renderer_1 = require("./renderer");
const core_1 = require("../core");
const utils_1 = require("../utils");
let examplesPanel;
function showExamples(context, langClient) {
    if (examplesPanel) {
        examplesPanel.reveal();
        return;
    }
    // Create and show a new webview
    examplesPanel = vscode_1.window.createWebviewPanel('ballerinaExamples', "Ballerina Examples", { viewColumn: vscode_1.ViewColumn.One, preserveFocus: false }, {
        enableScripts: true,
        retainContextWhenHidden: true,
    });
    const remoteMethods = [
        {
            methodName: "openExample",
            handler: (args) => {
                const url = args[0];
                const ballerinaHome = core_1.ballerinaExtInstance.getBallerinaHome();
                if (ballerinaHome) {
                    const folderPath = path.join(ballerinaHome, 'examples', url);
                    const filePath = path.join(folderPath, `${url.replace(/-/g, '_')}.bal`);
                    vscode_1.workspace.openTextDocument(vscode_1.Uri.file(filePath)).then(doc => {
                        vscode_1.window.showTextDocument(doc);
                    }, (err) => {
                        vscode_1.window.showErrorMessage(err.message);
                    });
                }
                return Promise.resolve();
            }
        }
    ];
    utils_1.WebViewRPCHandler.create(examplesPanel.webview, langClient, remoteMethods);
    const html = renderer_1.render(context, langClient);
    if (examplesPanel && html) {
        examplesPanel.webview.html = html;
    }
    examplesPanel.onDidDispose(() => {
        examplesPanel = undefined;
    });
}
function activate(ballerinaExtInstance) {
    let context = ballerinaExtInstance.context;
    let langClient = ballerinaExtInstance.langClient;
    const examplesListRenderer = vscode_1.commands.registerCommand('ballerina.showExamples', () => {
        ballerinaExtInstance.onReady()
            .then(() => {
            const { experimental } = langClient.initializeResult.capabilities;
            const serverProvidesExamples = experimental && experimental.examplesProvider;
            if (!serverProvidesExamples) {
                ballerinaExtInstance.showMessageServerMissingCapability();
                return;
            }
            showExamples(context, langClient);
        })
            .catch((e) => {
            if (!ballerinaExtInstance.isValidBallerinaHome()) {
                ballerinaExtInstance.showMessageInvalidBallerinaHome();
            }
            else {
                ballerinaExtInstance.showPluginActivationError();
            }
        });
    });
    context.subscriptions.push(examplesListRenderer);
}
exports.activate = activate;
//# sourceMappingURL=activator.js.map