'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Copyright (c) 2018, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
const vscode_languageclient_1 = require("vscode-languageclient");
exports.BALLERINA_LANG_ID = "ballerina";
class ExtendedLangClient extends vscode_languageclient_1.LanguageClient {
    getAST(uri) {
        const req = {
            documentIdentifier: {
                uri: uri.toString()
            }
        };
        return this.sendRequest("ballerinaDocument/ast", req);
    }
    triggerASTDidChange(ast, uri) {
        const evt = {
            textDocumentIdentifier: {
                uri: uri.toString(),
            },
            ast
        };
        return this.sendRequest("ballerinaDocument/astDidChange", evt);
    }
    fetchExamples(args = {}) {
        return this.sendRequest("ballerinaExample/list", args);
    }
    parseFragment(args) {
        return this.sendRequest("ballerinaFragment/ast", args).then((resp) => resp.ast);
    }
    getEndpoints() {
        return this.sendRequest("ballerinaSymbol/endpoints", {})
            .then((resp) => resp.endpoints);
    }
    getBallerinaOASDef(uri, oasService) {
        const req = {
            ballerinaDocument: {
                uri: uri.toString()
            },
            ballerinaService: oasService
        };
        return this.sendRequest("ballerinaDocument/openApiDefinition", req);
    }
    triggerOpenApiDefChange(oasJson, uri) {
        const req = {
            oasDefinition: oasJson,
            documentIdentifier: {
                uri: uri.toString()
            },
        };
        return this.sendNotification("ballerinaDocument/apiDesignDidChange", req);
    }
    getServiceListForActiveFile(uri) {
        const req = {
            documentIdentifier: {
                uri: uri.toString()
            },
        };
        return this.sendRequest("ballerinaDocument/serviceList", req);
    }
    getBallerinaProject(params) {
        return this.sendRequest("ballerinaDocument/project", params);
    }
    getDefinitionPosition(params) {
        return this.sendRequest("textDocument/definition", params)
            .then((res) => {
            console.log(res);
            const definitions = res;
            if (!(definitions.length > 0)) {
                return Promise.reject();
            }
            return definitions[0];
        });
    }
}
exports.ExtendedLangClient = ExtendedLangClient;
//# sourceMappingURL=extended-language-client.js.map