"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_1 = require("vscode");
const index_1 = require("../core/index");
const debugConfigProvider = {
    resolveDebugConfiguration(folder, config) {
        const ballerinaHome = index_1.ballerinaExtInstance.getBallerinaHome();
        if (!ballerinaHome) {
            index_1.ballerinaExtInstance.showMessageInstallBallerina();
            return;
        }
        else {
            config['ballerina.home'] = ballerinaHome;
        }
        if (!config.type) {
            config.type = 'ballerina';
        }
        if (!config.request) {
            config.request = 'launch';
        }
        if (!config.script) {
            if (!vscode_1.window.activeTextEditor) {
                index_1.ballerinaExtInstance.showMessageInvalidFile();
                return;
            }
            const activeDoc = vscode_1.window.activeTextEditor.document;
            if (!activeDoc.fileName.endsWith('.bal')) {
                index_1.ballerinaExtInstance.showMessageInvalidFile();
                return;
            }
            config.script = vscode_1.window.activeTextEditor.document.uri.path;
        }
        let langClient = index_1.ballerinaExtInstance.langClient;
        if (langClient.initializeResult) {
            const { experimental } = langClient.initializeResult.capabilities;
            if (experimental && experimental.introspection && experimental.introspection.port > 0) {
                config.networkLogsPort = experimental.introspection.port;
                if (config.networkLogs === undefined) {
                    config.networkLogs = true;
                }
            }
        }
        return config;
    }
};
function activateDebugConfigProvider(ballerinaExtInstance) {
    let context = ballerinaExtInstance.context;
    context.subscriptions.push(vscode_1.debug.registerDebugConfigurationProvider('ballerina', debugConfigProvider));
}
exports.activateDebugConfigProvider = activateDebugConfigProvider;
//# sourceMappingURL=config-provider.js.map