'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("./core");
const api_editor_1 = require("./api-editor");
const diagram_1 = require("./diagram");
const bbe_1 = require("./bbe");
const docs_1 = require("./docs");
const trace_logs_1 = require("./trace-logs");
const debugger_1 = require("./debugger");
const test_runner_1 = require("./test-runner");
const project_1 = require("./project");
// TODO initializations should be contributions from each component
function onBeforeInit(langClient) {
    class TraceLogsFeature {
        fillClientCapabilities(capabilities) {
            capabilities.experimental = capabilities.experimental || {};
            capabilities.experimental.introspection = true;
        }
        initialize(capabilities, documentSelector) {
        }
    }
    class ShowFileFeature {
        fillClientCapabilities(capabilities) {
            capabilities.experimental = capabilities.experimental || {};
            capabilities.experimental.showTextDocument = true;
        }
        initialize(capabilities, documentSelector) {
        }
    }
    langClient.registerFeature(new TraceLogsFeature());
    langClient.registerFeature(new ShowFileFeature());
}
function activate(context) {
    core_1.ballerinaExtInstance.setContext(context);
    return core_1.ballerinaExtInstance.init(onBeforeInit).then(() => {
        // start the features.
        // Enable Ballerina diagram
        diagram_1.activate(core_1.ballerinaExtInstance);
        // Enable Ballerina by examples
        bbe_1.activate(core_1.ballerinaExtInstance);
        // Enable Network logs
        trace_logs_1.activate(core_1.ballerinaExtInstance);
        // Enable Ballerina Debug Config Provider
        debugger_1.activateDebugConfigProvider(core_1.ballerinaExtInstance);
        // Enable Test Runner
        test_runner_1.activateTestRunner(core_1.ballerinaExtInstance);
        // Enable API Docs Live Preview
        docs_1.activate(core_1.ballerinaExtInstance);
        debugger_1.activateDebugConfigProvider(core_1.ballerinaExtInstance);
        // Enable Ballerina API Designer
        api_editor_1.activate(core_1.ballerinaExtInstance);
        // Enable Ballerina Project related features
        project_1.activate(core_1.ballerinaExtInstance);
    });
}
exports.activate = activate;
//# sourceMappingURL=extension.js.map