"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("../core");
const vscode_1 = require("vscode");
function promptOpenFolder(path) {
    if (vscode_1.workspace.workspaceFolders) {
        const folder = vscode_1.workspace.workspaceFolders.find((folder) => {
            return folder.uri.fsPath === path;
        });
        if (folder) {
            return;
        }
    }
    const action = "Open Project";
    vscode_1.window.showInformationMessage("File resides within a Ballerina project at " +
        path, action)
        .then((selection) => {
        if (selection === action) {
            vscode_1.workspace.updateWorkspaceFolders(0, 0, { uri: vscode_1.Uri.file(path) });
        }
    });
}
function activate(ballerinaExtInstance) {
    let langClient = ballerinaExtInstance.langClient;
    // when a new file is opened, detect if it resides inside a project
    // and notify user
    vscode_1.workspace.onDidOpenTextDocument((document) => {
        if (document.languageId === core_1.BALLERINA_LANG_ID) {
            langClient.getBallerinaProject({
                documentIdentifier: {
                    uri: document.uri.toString()
                }
            }).then((project) => {
                if (project.path) {
                    promptOpenFolder(project.path);
                }
            });
        }
    });
}
exports.activate = activate;
//# sourceMappingURL=activator.js.map