"use strict";
/**
 * Copyright (c) 2018, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_1 = require("vscode");
const renderer_1 = require("./renderer");
const utils_1 = require("../utils");
const traces_1 = require("./traces");
let traceLogsPanel;
let traceDetailsPanel;
let traces = new traces_1.default();
let status;
function showTraces(context, langClient) {
    if (traceLogsPanel) {
        traceLogsPanel.dispose();
    }
    // Create and show a new webview
    traceLogsPanel = vscode_1.window.createWebviewPanel('ballerinaNetworkLogs', "Ballerina Network logs", { viewColumn: vscode_1.ViewColumn.Two, preserveFocus: true }, {
        enableScripts: true,
        retainContextWhenHidden: false,
    });
    const html = renderer_1.render(context, langClient);
    if (traceLogsPanel && html) {
        traceLogsPanel.webview.html = html;
        traceLogsPanel.webview.postMessage({
            command: 'updateTraces',
        });
    }
    const remoteMethods = [
        {
            methodName: 'showDetails',
            handler: (trace) => {
                if (traceDetailsPanel) {
                    traceDetailsPanel.reveal(traceDetailsPanel.viewColumn);
                    const html = renderer_1.renderDetailView(context, langClient, trace);
                    traceDetailsPanel.webview.html = html;
                    return Promise.resolve();
                }
                // TODO: optimize this logic to reuse existing traceDetailsPanel
                traceDetailsPanel = vscode_1.window.createWebviewPanel('ballerinaNetworkLogsDetails', "Ballerina Network Log Details", { viewColumn: vscode_1.ViewColumn.Beside }, {
                    enableScripts: true,
                    retainContextWhenHidden: false,
                });
                const html = renderer_1.renderDetailView(context, langClient, trace);
                traceDetailsPanel.webview.html = html;
                traceDetailsPanel.onDidDispose(() => {
                    traceDetailsPanel = undefined;
                });
                return Promise.resolve();
            }
        },
        {
            methodName: 'getTraces',
            handler: (args) => {
                return Promise.resolve(traces.getTraces());
            }
        },
        {
            methodName: 'clearLogs',
            handler: () => {
                traces = new traces_1.default();
                updateStatus();
                if (traceLogsPanel && traceLogsPanel.webview) {
                    traceLogsPanel.webview.postMessage({
                        command: 'updateTraces',
                    });
                }
                return Promise.resolve();
            }
        },
    ];
    utils_1.WebViewRPCHandler.create(traceLogsPanel.webview, langClient, remoteMethods);
    traceLogsPanel.onDidDispose(() => {
        traceDetailsPanel.dispose();
        traceLogsPanel = undefined;
    });
}
function activate(ballerinaExtInstance) {
    let context = ballerinaExtInstance.context;
    let langClient = ballerinaExtInstance.langClient;
    status = vscode_1.window.createStatusBarItem(vscode_1.StatusBarAlignment.Left, 100);
    status.command = 'ballerina.showTraces';
    context.subscriptions.push(status);
    updateStatus();
    ballerinaExtInstance.onReady().then(() => {
        langClient.onNotification('window/traceLogs', (trace) => {
            addNewTrace(trace);
            updateStatus();
            if (traceLogsPanel && traceLogsPanel.webview) {
                traceLogsPanel.webview.postMessage({
                    command: 'updateTraces',
                });
            }
        });
    })
        .catch((e) => {
        vscode_1.window.showErrorMessage('Could not start network logs feature', e.message);
    });
    const traceRenderer = vscode_1.commands.registerCommand('ballerina.showTraces', () => {
        showTraces(context, langClient);
    });
    context.subscriptions.push(traceRenderer);
}
exports.activate = activate;
function addNewTrace(trace) {
    traces.addTrace(trace);
}
function updateStatus() {
    if (!status) {
        return;
    }
    const count = traces.getTraces().length;
    status.text = `$(mirror) ${count} Ballerina network logs`;
    status.show();
}
//# sourceMappingURL=activator.js.map